/************************************************************************/
/*																		*/
/*	Dspi.h	--	Interface Declarations for PIC32 SPI PORTS				*/
/*																		*/
/************************************************************************/
/*	Author:		Oliver Jones											*/
/*	Copyright 2011, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*																		*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	07/07/2011(OliverJ): created										*/
/*																		*/
/************************************************************************/

#if !defined(DSPI_INC)
#define DSPI_INC

#include "Dport.h"

/* ------------------------------------------------------------ */
/*					Miscellaneous Declarations					*/
/* ------------------------------------------------------------ */

typedef struct {
	int type;
	portHIF portSS;
	unsigned int pinSS;
	union {
		struct {
			int portNumber;
			unsigned int * pConSet;
			unsigned int * pConClr;
			unsigned int * pStat;
			unsigned int * pStatSet;
			unsigned int * pStatClr;
			unsigned int * pBaud;
			unsigned int * pBuffer;
		} spiHardware;	
		struct {
			BOOL fEnabled;
			int mode;
			portHIF portClk;
			unsigned int pinClk;
			portHIF portMosi;
			unsigned int pinMosi;
			portHIF portMiso;
			unsigned int pinMiso;
		} spiBitBang;
	} spiCon;
}spiHIF;

#define modSpiHardware 0
#define modSpiBitBang 1

//Spi Port Values
#define spi0 0
#define spi1 1
#define spi2 2
#define spi3 3
#define spi4 4

//Spi mode Value
#define spiMod0	0x0000
#define spiMod1	0x0100
#define spiMod2	0x0040
#define spiMod3	0x0140

//Bit Masks
#define bmSpiMod 0x140

//Error Codes

/* ------------------------------------------------------------ */
/*					General Type Declarations					*/
/* ------------------------------------------------------------ */

/*	SPIxCON
*/
#define	bnFrmen				31
#define	bnFrmsync			30
#define	bnFrmpol			29
#define	bnMssen				28
#define	bnFrmsypw			27
#define	bnFrmcnt2			26
#define	bnFrmcnt1			25
#define	bnFrmcnt0			24
// Bits 23-18 Reserved
#define	bnSpife				17
#define	bnEnhbuf			16
#define	bnOn				15
#define	bnFrz				14
#define	bnSidl				13
#define	bnDissdo			12
#define	bnMode1				11
#define	bnMode0				10
#define	bnSmp				9
#define	bnCke				8
#define	bnSsen				7
#define	bnCkp				6
#define	bnMsten				5
// Bit 4 Reserved
#define	bnStxisel1			3
#define	bnStxisel0			2
#define	bnRtxisel1			1
#define	bnRtxisel0			0
/*******************************/

/*	SPIxSTAT
*/
// Bits 31-29 Reserved
#define	bnRxbufelm4			28
#define	bnRxbufelm3			27
#define	bnRxbufelm2			26
#define	bnRxbufelm1			25
#define	bnRxbufelm0			24
// Bits 23-21 Reserved
#define	bnTxbufelm4			20
#define	bnTxbufelm3			19
#define	bnTxbufelm2			18
#define	bnTxbufelm1			17
#define	bnTxbufelm0			16
// Bits 15-12 Reserved
#define	bnSpitur			8
#define	bnSrmt				7
#define	bnSpirov			6
#define	bnSpirbe			5
// Bit 4 Reserved	
#define	bnSpitbe			3
// Bit 2 Reserved
#define	bnSpitbf			1
#define	bnSpirbf			0
/*******************************/

/* ------------------------------------------------------------ */
/*					Procedure Declarations						*/
/* ------------------------------------------------------------ */

BOOL DspiGetHandle(spiHIF * hif, unsigned int prtReq);
void DspiEnable(spiHIF * hif);
void DspiDisable(spiHIF * hif);
BOOL DspiSetPinSS(spiHIF * hif, char chPort, unsigned int pin);
BOOL DspiSetPinClk(spiHIF * hif, char chPort, unsigned int pin);
BOOL DspiSetPinMosi(spiHIF * hif, char chPort, unsigned int pin);
BOOL DspiSetPinMiso(spiHIF * hif, char chPort, unsigned int pin);
BOOL DspiSetSelect(spiHIF * hif, BOOL fSel);
void DspiSetSpiMode(spiHIF * hif, DWORD idMod);
void DspiSetSpeed(spiHIF * hif, DWORD frqReq);
BOOL DspiPutByte(spiHIF * hif, BOOL fSelStart, BOOL fSelEnd, BYTE bSnd,BYTE * pbRcv);
BOOL DspiPut(spiHIF * hif, BOOL fSelStart, BOOL fSelEnd, BYTE * rgbSnd,BYTE * pbRcv, DWORD cbSend);
BOOL DspiGet(spiHIF * hif, BOOL fSelStart, BOOL fSelEnd, BYTE * pbRcv, DWORD cbRcv);

#endif
