/************************************************************************/
/*																		*/
/*	main.c	--	Example project for PmodSF								*/
/*																		*/
/************************************************************************/
/*	Author:		Michelle Yu												*/
/*	Copyright 2011, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This project demonstrate the functionality of a PmodSF 			*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	07/29/2011(MichelleY): created										*/
/*																		*/
/************************************************************************/
#include "PmodSF.h"
#include "Dspi.h"



int main(void)
{

	spiHIF myspi;

	int chipModel;
	int maxAdd;
	int i = 0;
	BYTE wdata[256]={0}; // initialize the write data to 0
	BYTE rdata[256]={0}; // initialize the read data to 0
	
	// Initialize SPI using spi2 and connector JB
	DspiGetHandle(&myspi, spi2);
	DspiEnable(&myspi);
	DspiSetPinSS(&myspi, 'G', 9);
	DspiSetSpiMode(&myspi, 0x8020);
	DspiSetSpeed(&myspi, 40000000);

	//Get Device Info, this should be at the beginning of the program	
	chipModel= GetDeviceInfo(&myspi, &maxAdd);


	//Unprotect all areas so that bulk erase can work
	WriteProtect(&myspi, 0x00); 	
	//erase all the data on the PmodSF
	BulkErase(&myspi);

	//Read 256 bytes into rdata at a normal speed
	//read a sector and make sure it is erased
	NormalRead(&myspi, rdata, 0x000000, 256);

	//Write
	//load wdata with some data 
	//the size of wdata should be less or equal to 256 Bytes
	//anything over 256 bytes will be wrap around and override the first bytes 
	while(i<256)
	{
		wdata[i++] = 0x25;
	}
	WritePage(&myspi, wdata, 0x110000, 256);
	
	//read back the data written
	NormalRead(&myspi, rdata, 0x110000, 256);

	//Erase the sector that the address parameter is in  
	// in this case address 110000 is in sector 17
	// therefor sector 17 will be erased entirely
	SectorErase(&myspi, 0x110000);

	//read 256 bytes of data at a fast speed 
	//verify that the data has been erased
	FastRead(&myspi, rdata, 0x110000, 256);

	
	//protect all area from write/erase
	WriteProtect(&myspi, 0x04); 
	//try to write to a unprotected sector
	WritePage(&myspi, wdata, 0x000000, 1);
	//check if the device is unprotected against write
	//if the rdata does not come back with data, it is protected
	NormalRead(&myspi, rdata, 0x000000, 1);

	//try to write to a protected sector
	WritePage(&myspi, wdata, 0x1F0000, 1);
	//check if the device is protected against write
	//if the rdata does not come back with data, it is protected
	NormalRead(&myspi, rdata, 0x1F0000, 1);


	//Puts the device to sleep then wake 
	//NOTE: this two function is only available on M25P16
	if(chipModel == 0x16)
	{
		//puts the device in a low power consumption mode
		Sleep(&myspi);
		//check if command still work, if not means it is asleep
		WritePage(&myspi, wdata, 0x000000, 256);
		NormalRead(&myspi, rdata, 0x000000, 256);
	
		//wake up the device
		Wake(&myspi);
	
		//check if the device is awake
		//if the rdata comes back with data, it is awake
		WritePage(&myspi, wdata, 0x000000, 256);
		NormalRead(&myspi, rdata, 0x000000, 256);
	}

}





